'use strict';

var _chai = require('chai');

var _nock = require('nock');

var _nock2 = _interopRequireDefault(_nock);

var _dist = require('../dist');

var _dist2 = _interopRequireDefault(_dist);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
describe('errors', function () {

  it('status: 1', function (done) {
    (0, _nock2.default)(_utils.ROOT).get('/error1').reply(200, {
      status: 0
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/error1',
      handler: function handler(json) {
        var a = 1;
        a.b = 2;
        return json;
      },
      error: function error(res) {
        if (res.status === 4) {
          var a = 1;
          a.b = 2;
        }
        (0, _chai.expect)(res.status).to.be.equal(1);
        (0, _chai.expect)(res.error).to.be.an('error');
      }
    }).send().then(done).catch(done);
  });

  it('status: 2', function (done) {
    (0, _nock2.default)(_utils.ROOT).get('/error2').reply(500, {
      status: 0
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/error2',
      error: function error(res) {
        (0, _chai.expect)(res.status).to.be.equal(2);
        (0, _chai.expect)(res.httpStatus).to.be.equal(500);
      }
    }).send().then(done).catch(done);
  });

  it('status: 3', function (done) {
    (0, _nock2.default)(_utils.ROOT).get('/error3').reply(200, {
      status: -1,
      message: 'wrong request'
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/error3',
      error: function error(res) {
        (0, _chai.expect)(res.status).to.be.equal(3);
        (0, _chai.expect)(res.data.status).to.be.equal(-1);
      }
    }).send().then(done).catch(done);
  });

  it('status: 4 (from handler)', function (done) {
    (0, _nock2.default)(_utils.ROOT).get('/error4').reply(200, {
      status: 0
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/error4',
      handler: function handler(json) {
        var a = 1;
        a.b = 2;
        return json;
      },
      error: function error(res) {
        (0, _chai.expect)(res.status).to.be.equal(4);
        (0, _chai.expect)(res.error).to.be.an('error');
      }
    }).send().then(done).catch(done);
  });

  it('status: 4 (from success)', function (done) {
    (0, _nock2.default)(_utils.ROOT).get('/error4').reply(200, {
      status: 0
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/error4',
      success: function success(res) {
        (0, _chai.expect)(res.status).to.be.equal(0);
        var a = 1;
        a.b = 2;
      },
      error: function error(res) {
        (0, _chai.expect)(res.status).to.be.equal(4);
        (0, _chai.expect)(res.error).to.be.an('error');
      }
    }).send().then(done).catch(done);
  });

  it('status: 5 (timeout)', function (done) {
    (0, _nock2.default)(_utils.ROOT).get('/error5').delayConnection(200).reply(200, {
      status: 0
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/error5',
      timeout: 100,
      error: function error(res) {
        (0, _chai.expect)(res.status).to.be.equal(5);
        (0, _chai.expect)(res.timeout).to.be.equal(100);
        return res;
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.be.equal(5);
    }).then(done).catch(done);
  });

  it('status: 5 (no timeout)', function (done) {
    (0, _nock2.default)(_utils.ROOT).get('/error5').delayConnection(200).reply(200, {
      status: 0
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/error5',
      timeout: 300,
      success: function success(res) {
        (0, _chai.expect)(res.status).to.be.equal(0);
        return res;
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.be.equal(0);
    }).then(done).catch(done);
  });
});
//# sourceMappingURL=errors.spec.js.map