'use strict';

var _chai = require('chai');

var _nock = require('nock');

var _nock2 = _interopRequireDefault(_nock);

var _qs = require('qs');

var _qs2 = _interopRequireDefault(_qs);

var _formData = require('form-data');

var _formData2 = _interopRequireDefault(_formData);

var _dist = require('../dist');

var _dist2 = _interopRequireDefault(_dist);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-unused-expressions: 0 */
describe('get/post', function () {

  it('get user1', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1'
      }
    }).get('/user').query({
      uid: 1
    }).reply(200, {
      name: 'user1'
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      query: {
        uid: 1
      },
      headers: {
        'X-My-Headers': '1'
      },
      success: function success(res) {
        (0, _chai.expect)(res.name).to.be.equal('user1');
        return res;
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.name).to.be.equal('user1');
    }).then(done).catch(done);
  });

  it('get user2', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1'
      }
    }).get('/user').query({
      uid: 2
    }).reply(200, {
      name: 'user2'
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      query: {
        uid: 2
      },
      headers: {
        'X-My-Headers': '1'
      },
      success: function success(res) {
        (0, _chai.expect)(res.name).to.be.equal('user2');
        return res;
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.name).to.be.equal('user2');
    }).then(done).catch(done);
  });

  it('post user3 by urlencoded', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1'
      }
    }).post('/user').query({
      uid: 3
    }).reply(200, function (uri, requestBody) {
      return Object.assign(_qs2.default.parse(requestBody), {
        status: 0
      });
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 3
      },
      headers: {
        'X-My-Headers': '1'
      },
      data: {
        name: 'user3'
      },
      success: function success(res) {
        (0, _chai.expect)(res.name).to.be.equal('user3');
        (0, _chai.expect)(res.status).to.be.equal(0);
        return res;
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.be.equal(0);
    }).then(done).catch(done);
  });

  it('post user4 by JSON', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1'
      }
    }).post('/user').query({
      uid: 4
    }).reply(200, function (uri, requestBody) {
      return Object.assign(requestBody, {
        status: 0
      });
    });
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 4
      },
      headers: {
        'X-My-Headers': '1'
      },
      dataType: 'application/json',
      data: {
        name: 'user4'
      },
      success: function success(res) {
        (0, _chai.expect)(res.name).to.be.equal('user4');
        (0, _chai.expect)(res.status).to.be.equal(0);
        return res;
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.be.equal(0);
    }).then(done).catch(done);
  });

  it('post user5 by FormData', function (done) {
    (0, _nock2.default)(_utils.ROOT, {
      reqheaders: {
        'X-My-Headers': '1'
      }
    }).post('/user').query({
      uid: 5
    }).reply(200, function (uri, requestBody) {
      return Object.assign((0, _utils.parseFormData)(requestBody), {
        status: 0
      });
    });
    var formData = new _formData2.default();
    formData.append('name', 'user5');
    (0, _dist2.default)({
      url: _utils.ROOT + '/user',
      method: 'post',
      query: {
        uid: 5
      },
      headers: {
        'X-My-Headers': '1'
      },
      dataType: 'multipart/form-data',
      data: formData,
      success: function success(res) {
        (0, _chai.expect)(res.name).to.be.equal('user5');
        (0, _chai.expect)(res.status).to.be.equal(0);
        return res;
      }
    }).send().then(function (res) {
      (0, _chai.expect)(res.status).to.be.equal(0);
    }).then(done).catch(done);
  });
});
//# sourceMappingURL=getpost.spec.js.map